/* Copyright (C) 2017 Mono Wireless Inc. All Rights Reserved.    *
 * Released under MW-SLA-*J,*E (MONO WIRELESS SOFTWARE LICENSE   *
 * AGREEMENT).                                                   */

/*
 * シリアル書式(ASCII, BINARY) 生成プログラム
 *   テキストを１行ずつ読み込んで、この内容をそのまま ASCII または BINARY 書式に出力します。
 *   本プログラムは sercmd_test の確認用に作製しています。
 *
 *   実行例:
 *   $ echo 1234 | ./sercmd_gen | ./sercmd_test
 *
 *   オプション:
 *     -b   バイナリ書式
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/*
 * シリアルパーサーの API
 */
#include "jendefs.h"
#include "sercmd_gen.h"

// システムの ms タイマーカウンター。タイムアウト機能を使わないなら 0 を入れておく。
uint32 u32TickCount_ms = 0;
// vOutput() で書式出力するときの１バイト出力用の関数
void vPutChar_STDOUT(uint8 u8char) {
	putchar(u8char);
}

/*
 * シリアルコマンドの解釈構造体
 */
tsSerCmd_Context serCmd;
int fBinMode = 0;

/*
 * バッファの初期化
 */
void initSerCmd(int fBinMode) {
	static uint8 u8buf[255]; // 入力系列を保持するバッファ
	if (fBinMode) {
		SerCmdBinary_vInit(&serCmd, u8buf, sizeof(u8buf));
	} else {
		SerCmdAscii_vInit(&serCmd, u8buf, sizeof(u8buf));
	}

	serCmd.vPutChar = vPutChar_STDOUT; // 出力用の関数を登録
}

int main(int argc, char *argv[]) {
	char keyinput[255];
	// 入力オプションのチェック
	int fBinMode = 0;
	if (argc >= 2 && !strcmp(argv[1], "-b")) {
		fBinMode = 1;
	}

	// 系列の初期化
	initSerCmd(fBinMode);

	while (1) {
		if (fgets(keyinput, sizeof(keyinput), stdin) != NULL) {
			serCmd.u16len = strlen(keyinput) - 1;
			if (serCmd.u16len > 0) {
				memcpy(serCmd.au8data, keyinput, serCmd.u16len);
				serCmd.vOutput(&serCmd);
			}
		} else {
			break;
		}
	}
}
